@@ -1,11 +1,11 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: vector-binary-instances
-version: 0.2.1.0
-id: vector-binary-instances-0.2.1.0-2402c80907803c40cc3e5d11aff3bc9a
-key: vecto_KO8K6e6cxMY4EjOuI22EJr
+version: 0.2.1.1
+id: vector-binary-instances-0.2.1.1-c0febfb5ca69d46d3d7932a3e5b87de1
+key: vecto_CBpitSy1URqJ55rwnmqL4b
 license: BSD3
-maintainer: dons00@gmail.com, bos@serpentine.com
+maintainer: dons00@gmail.com, bos@serpentine.com, Ben Gamari <ben@smart-cactus.org>
 stability: Experimental
 homepage: https://github.com/bos/vector-binary-instances
 synopsis: Instances of Data.Binary and Data.Serialize for vector
@@ -32,16 +32,15 @@ category: Data
 author: Don Stewart
 exposed: True
 exposed-modules:
-    Data.Vector.Binary Data.Vector.Cereal
+    Data.Vector.Binary
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/vector-binary-instances-0.2.1.0
-library-dirs: /usr/lib/ghc-7.10.3/site-local/vector-binary-instances-0.2.1.0
-data-dir: /usr/share/arm-linux-ghc-7.10.3/vector-binary-instances-0.2.1.0
-hs-libraries: HSvector-binary-instances-0.2.1.0-KO8K6e6cxMY4EjOuI22EJr
+import-dirs: /usr/lib/ghc-7.10.3/site-local/vector-binary-instances-0.2.1.1
+library-dirs: /usr/lib/ghc-7.10.3/site-local/vector-binary-instances-0.2.1.1
+data-dir: /usr/share/arm-linux-ghc-7.10.3/vector-binary-instances-0.2.1.1
+hs-libraries: HSvector-binary-instances-0.2.1.1-CBpitSy1URqJ55rwnmqL4b
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
-    cereal-0.5.1.0-2c7be146776a4abf674d1ac9e0ccfc13
     vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
 haddock-interfaces: /usr/share/doc/haskell-vector-binary-instances/html/vector-binary-instances.haddock
 haddock-html: /usr/share/doc/haskell-vector-binary-instances/html
